@@ -9,7 +9,12 @@ from click import BadParameter
 
 from neuro_sdk import LocalImage, RemoteImage, TagOption
 
-from .parse_utils import JobColumnInfo, parse_columns, to_megabytes
+from .parse_utils import (
+    JobColumnInfo,
+    parse_ps_columns,
+    parse_top_columns,
+    to_megabytes,
+)
 from .root import Root
 
 # NOTE: these job name defaults are taken from `platform_api` file `validators.py`
@@ -72,18 +77,6 @@ class LocalImageType(click.ParamType):
         return client.parse.local_image(value)
 
 
-class ImageType(click.ParamType):
-    name = "image"
-
-    def convert(
-        self, value: str, param: Optional[click.Parameter], ctx: Optional[click.Context]
-    ) -> RemoteImage:
-        assert ctx is not None
-        root = cast(Root, ctx.obj)
-        client = root.run(root.init_client())
-        return client.parse.remote_image(value)
-
-
 class RemoteTaglessImageType(click.ParamType):
     name = "image"
 
@@ -99,13 +92,16 @@ class RemoteTaglessImageType(click.ParamType):
 class RemoteImageType(click.ParamType):
     name = "image"
 
+    def __init__(self, tag_option: TagOption = TagOption.DEFAULT) -> None:
+        self.tag_option = tag_option
+
     def convert(
         self, value: str, param: Optional[click.Parameter], ctx: Optional[click.Context]
     ) -> RemoteImage:
         assert ctx is not None
         root = cast(Root, ctx.obj)
         client = root.run(root.init_client())
-        return client.parse.remote_image(value)
+        return client.parse.remote_image(value, tag_option=self.tag_option)
 
 
 class LocalRemotePortParamType(click.ParamType):
@@ -202,12 +198,29 @@ class JobColumnsType(click.ParamType):
     ) -> List[JobColumnInfo]:
         if isinstance(value, list):
             return value
-        return parse_columns(value)
+        return parse_ps_columns(value)
 
 
 JOB_COLUMNS = JobColumnsType()
 
 
+class TopColumnsType(click.ParamType):
+    name = "columns"
+
+    def convert(
+        self,
+        value: Union[str, List[JobColumnInfo]],
+        param: Optional[click.Parameter],
+        ctx: Optional[click.Context],
+    ) -> List[JobColumnInfo]:
+        if isinstance(value, list):
+            return value
+        return parse_top_columns(value)
+
+
+TOP_COLUMNS = TopColumnsType()
+
+
 class PresetType(AsyncType[str]):
     name = "preset"
 
