@@ -17,12 +17,14 @@ from yarl import URL
 
 from neuro_sdk import (
     PASS_CONFIG_ENV_NAME,
+    Action,
     AuthorizationError,
     Client,
     HTTPPort,
     JobDescription,
     JobRestartPolicy,
     JobStatus,
+    Permission,
     RemoteImage,
     Volume,
 )
@@ -966,6 +968,12 @@ async def kill(root: Root, jobs: Sequence[str]) -> None:
     show_default=True,
     help="Run job in privileged mode, if it is supported by cluster.",
 )
+@option(
+    "--share",
+    metavar="USER",
+    multiple=True,
+    help=("Share job write permissions to user or role."),
+)
 @TTY_OPT
 async def run(
     root: Root,
@@ -995,6 +1003,7 @@ async def run(
     tty: Optional[bool],
     schedule_timeout: Optional[str],
     privileged: bool,
+    share: Sequence[str],
 ) -> None:
     """
     Run a job with predefined resources configuration.
@@ -1053,6 +1062,7 @@ async def run(
         tty=tty,
         schedule_timeout=schedule_timeout,
         privileged=privileged,
+        share=share,
     )
 
 
@@ -1125,6 +1135,7 @@ async def run_job(
     tty: bool,
     schedule_timeout: Optional[str],
     privileged: bool,
+    share: Sequence[str],
 ) -> JobDescription:
     if http_auth is None:
         http_auth = True
@@ -1190,7 +1201,9 @@ async def run_job(
         # TODO: remove this and upload_and_map_config function
         old_env_name = "NEURO_STEAL_CONFIG"
         if old_env_name in env_dict:
-            raise ValueError(f"{env_name} is already set to {env_dict[env_name]}")
+            raise ValueError(
+                f"{old_env_name} is already set to {env_dict[old_env_name]}"
+            )
 
         env_var, secret_volume = await upload_and_map_config(root)
         env_dict[old_env_name] = env_var
@@ -1227,6 +1240,9 @@ async def run_job(
         schedule_timeout=job_schedule_timeout,
         privileged=privileged,
     )
+    permission = Permission(job.uri, Action.WRITE)
+    for user in share:
+        await root.client.users.share(user, permission)
     with JobStartProgress.create(console=root.console, quiet=root.quiet) as progress:
         progress.begin(job)
         while wait_start and job.status == JobStatus.PENDING:
@@ -1384,6 +1400,8 @@ def _job_to_cli_args(job: JobDescription) -> List[str]:
     if job.description:
         res += ["--description", shlex.quote(job.description)]
     for volume in job.container.volumes:
+        if volume.container_path == "/var/storage/.neuro" and job.pass_config:
+            continue
         res += [
             "--volume",
             (
@@ -1403,7 +1421,7 @@ def _job_to_cli_args(job: JobDescription) -> List[str]:
     if job.container.working_dir:
         res += ["--workdir", job.container.working_dir]
     for env_name, env_value in job.container.env.items():
-        if env_name == PASS_CONFIG_ENV_NAME and job.pass_config:
+        if env_name in (PASS_CONFIG_ENV_NAME, "NEURO_STEAL_CONFIG") and job.pass_config:
             continue  # Do not specify value for pass config env variable
         res += ["--env", f"{env_name}={env_value}"]
     for env_name, secret_uri in job.container.secret_env.items():
