@@ -24,6 +24,7 @@ from neuro_sdk import get as api_get
 
 from neuro_cli.asyncio_utils import run
 
+from tests.e2e import make_image_name
 from tests.e2e.conftest import Helper
 
 pytestmark = pytest.mark.e2e_job
@@ -558,13 +559,13 @@ def test_e2e_ssh_exec_dead_job(helper: Helper) -> None:
                 "true",
             ]
         )
-    assert cm.value.returncode == 65
+    assert cm.value.returncode == 72
 
 
 @pytest.mark.e2e
 def test_job_save(helper: Helper, docker: aiodocker.Docker) -> None:
     job_name = f"test-job-save-{uuid4().hex[:6]}"
-    image = f"test-image:{job_name}"
+    image = f"{make_image_name()}:{job_name}"
     image_neuro_name = f"image://{helper.cluster_name}/{helper.username}/{image}"
     command = "sh -c 'echo -n 123 > /test; sleep 10m'"
     job_id_1 = helper.run_job_and_wait_state(
@@ -590,8 +591,6 @@ def test_job_save(helper: Helper, docker: aiodocker.Docker) -> None:
         image_neuro_name, command=command, wait_state=JobStatus.SUCCEEDED
     )
 
-    # TODO (A.Yushkovskiy): delete the pushed image in GCR
-
 
 @pytest.fixture
 async def nginx_job_async(
@@ -825,6 +824,32 @@ def test_job_run_browse(helper: Helper, fakebrowser: Any) -> None:
     assert "Browsing job, please open: https://job-" in captured.out
 
 
+@pytest.mark.e2e
+def test_job_run_share(helper: Helper, fakebrowser: Any) -> None:
+    another_test_user = "test2"
+    # Run a new job
+    captured = helper.run_cli(
+        [
+            "-q",
+            "job",
+            "run",
+            "--no-wait-start",
+            "--share",
+            another_test_user,
+            UBUNTU_IMAGE_NAME,
+            "true",
+        ]
+    )
+    job_id = captured.out.strip()
+
+    uri = f"job://{helper.cluster_name}/{helper.username}/{job_id}"
+    captured = helper.run_cli(["acl", "list", "--full-uri", "--shared", uri])
+    result = [line.split() for line in captured.out.splitlines()]
+    assert [uri, "write", another_test_user] in result
+
+    helper.run_cli(["acl", "revoke", uri, another_test_user])
+
+
 @pytest.mark.e2e
 def test_job_submit_no_detach_failure(helper: Helper) -> None:
     # Run a new job
