@@ -1,5 +1,6 @@
 import asyncio
 import sys
+from decimal import Decimal
 from pathlib import Path
 from typing import Callable
 from unittest import mock
@@ -27,7 +28,11 @@ def test_prompt_cluster(make_client: Callable[..., Client]) -> None:
             monitoring_url=URL("https://monitoring-dev.neu.ro"),
             secrets_url=URL("https://secrets-dev.neu.ro"),
             disks_url=URL("https://disks-dev.neu.ro"),
-            presets={"cpu-small": Preset(cpu=1, memory_mb=1024)},
+            presets={
+                "cpu-small": Preset(
+                    credits_per_hour=Decimal("10"), cpu=1, memory_mb=1024
+                )
+            },
             name="first",
         ),
         "second": Cluster(
@@ -38,7 +43,11 @@ def test_prompt_cluster(make_client: Callable[..., Client]) -> None:
             monitoring_url=URL("https://monitoring2-dev.neu.ro"),
             secrets_url=URL("https://secrets2-dev.neu.ro"),
             disks_url=URL("https://disks2-dev.neu.ro"),
-            presets={"cpu-small": Preset(cpu=2, memory_mb=1024)},
+            presets={
+                "cpu-small": Preset(
+                    credits_per_hour=Decimal("10"), cpu=2, memory_mb=1024
+                )
+            },
             name="second",
         ),
     }
@@ -89,7 +98,11 @@ def test_prompt_cluster_default(make_client: Callable[..., Client]) -> None:
             monitoring_url=URL("https://monitoring-dev.neu.ro"),
             secrets_url=URL("https://secrets-dev.neu.ro"),
             disks_url=URL("https://disks-dev.neu.ro"),
-            presets={"cpu-small": Preset(cpu=1, memory_mb=1024)},
+            presets={
+                "cpu-small": Preset(
+                    credits_per_hour=Decimal("10"), cpu=1, memory_mb=1024
+                )
+            },
             name="first",
         ),
         "second": Cluster(
@@ -100,7 +113,11 @@ def test_prompt_cluster_default(make_client: Callable[..., Client]) -> None:
             monitoring_url=URL("https://monitoring2-dev.neu.ro"),
             secrets_url=URL("https://secrets2-dev.neu.ro"),
             disks_url=URL("https://disks2-dev.neu.ro"),
-            presets={"cpu-small": Preset(cpu=2, memory_mb=1024)},
+            presets={
+                "cpu-small": Preset(
+                    credits_per_hour=Decimal("10"), cpu=2, memory_mb=1024
+                )
+            },
             name="second",
         ),
     }
